asr.core.results
================

.. automodule:: asr.core.results

   
   
   .. rubric:: Functions

   
   .. autofunction:: data_to_dict
   .. autofunction:: dct_to_result
   .. autofunction:: find_class_matching_version
   .. autofunction:: format_key_description_pair
   .. autofunction:: get_key_descriptions
   .. autofunction:: get_object_matching_obj_id
   .. autofunction:: get_object_types
   .. autofunction:: get_reader_function
   .. autofunction:: make_property
   .. autofunction:: obj_to_id
   .. autofunction:: object_description_to_object
   .. autofunction:: prepare_result
   .. autofunction:: read_hacked_data
   .. autofunction:: read_new_data
   .. autofunction:: read_old_data
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: ASRResult
      :members:
   .. autoclass:: DictEncoder
      :members:
   .. autoclass:: HTMLEncoder
      :members:
   .. autoclass:: HackedASRResult
      :members:
   .. autoclass:: JSONEncoder
      :members:
   .. autoclass:: MetaData
      :members:
   .. autoclass:: ObjectDescription
      :members:
   .. autoclass:: ResultEncoder
      :members:
   .. autoclass:: WebPanelEncoder
      :members:
   
   

   
   
   .. rubric:: Exceptions

   
   .. autoexception:: MetaDataNotSetError
   .. autoexception:: UnknownASRResultFormat
   .. autoexception:: UnknownDataFormat
   
   